@@ -19,7 +19,7 @@
 #' @param t A `Date` or numeric vector
 #' @references
 #' Peter M. Atkinson, et al., 2012, RSE, 123:400-417
-#'
+#' 
 #' @rdname logistics
 #' @export
 Logistic <- function(par, t){
@@ -31,10 +31,10 @@ Logistic <- function(par, t){
     # pred <- c/(1 + exp(a + b * t)) + d
     return(pred)
 }
-attr(Logistic, 'name')    <- 'Logistic'
 attr(Logistic, 'par')     <- c("mn", "mx", "sos", "rsp")
 attr(Logistic, 'formula') <- expression((mx - mn)/(1 + exp(-rsp*(t - sos))) + mn)
 
+# piecewise function
 #' @rdname logistics
 #' @export
 doubleLog.Zhang <- function(par, t){
@@ -46,7 +46,7 @@ doubleLog.Zhang <- function(par, t){
     eos <- par[6]
     rau <- par[7]
 
-    if (t0 - sos <= 1 || t0 - eos >= -1) return(rep(NA, length(t)))
+    if (t0 - sos <= 1 || t0 - eos >= -1) return(rep(99.0, length(t)))
     # In order to make sure the shape of S curve, should be satisfy:
     # t0 < eos, t0 > sos
 
@@ -59,15 +59,13 @@ doubleLog.Zhang <- function(par, t){
                          1 + exp( rau*(t[t >  t0] - eos))) + mn
     return(pred)
 }
-attr(doubleLog.Zhang, 'name')    <- 'doubleLog.Zhang'
 attr(doubleLog.Zhang, 'par')     <- c("t0", "mn", "mx", "sos", "rsp", "eos", "rau")
-# piecewise function
 attr(doubleLog.Zhang, 'formula') <- expression( (mx - mn)/(1 + exp(-rsp*(t - sos))),
                                                 (mx - mn)/(1 + exp( rau*(t - eos))) )
 
 #' @rdname logistics
 #' @export
-doubleAG <- function(par, t){
+doubleLog.AG <- function(par, t){
     t0  <- par[1]
     mn  <- par[2]
     mx  <- par[3]
@@ -79,13 +77,10 @@ doubleAG <- function(par, t){
     pred <- mn + (mx - mn)*exp(- c( ((t0 - t[t <= t0])*rsp) ^a3,
                     ((t[t >  t0] - t0)*rau) ^a5) )
     return(pred)
-    # pred <- (mx - mn)/c(1 + exp(-rsp*(t[t <= t0] - sos)),
-    #     1 + exp(-rau*(t[t >  t0] - eos))) + mn
 }
 # a3, a5 should be greater than 1
-attr(doubleAG, 'name')    <- 'doubleAG'
-attr(doubleAG, 'par')     <- c("t0", "mn", "mx", "rsp", "a3", "rau", "a5")
-attr(doubleAG, 'formula') <- expression( mn + (mx - mn)*exp(- ((t0 - t)*rsp) ^a3 ),
+attr(doubleLog.AG, 'par')     <- c("t0", "mn", "mx", "rsp", "a3", "rau", "a5")
+attr(doubleLog.AG, 'formula') <- expression( mn + (mx - mn)*exp(- ((t0 - t)*rsp) ^a3 ),
                                          mn + (mx - mn)*exp(- ((t - t0)*rau) ^a5 ))
 
 #' @rdname logistics
@@ -98,13 +93,13 @@ doubleLog.Beck <- function(par, t) {
     eos <- par[5]
     rau <- par[6]
     # if (sos >= eos) return(rep(9999, length(t)))
-    try(if (eos < sos) return(rep(99, length(t))), silent = TRUE)
+    # if (eos < sos) return(rep(99.0, length(t)))
+    if (!all(is.finite(par)) || eos < sos) return(rep(99.0, length(t)))
 
     pred <- mn + (mx - mn)*(1/(1 + exp(-rsp*(t - sos))) + 1/(1 + exp(rau*(t - eos))) - 1)
     return(pred)
 }
-attr(doubleLog.Beck, 'name') <- 'doubleLog.Beck'
-attr(doubleLog.Beck, 'par') <- c("mn", "mx", "sos", "rsp", "eos", "rau")
+attr(doubleLog.Beck, 'par')  <- c("mn", "mx", "sos", "rsp", "eos", "rau")
 attr(doubleLog.Beck, 'formula') <- expression(mn + (mx - mn)*(1/(1 + exp(-rsp*(t - sos))) + 1/(1 + exp(rau*(t - eos)))) - 1)
 
 #' @rdname logistics
@@ -128,8 +123,6 @@ doubleLog.Elmore <- function(par, t) {
     pred <- mn + (mx - m7*t)*( 1/(1 + exp(-rsp*(t-sos))) - 1/(1 + exp(-rau*(t-eos))) )
     return(pred)
 }
-
-attr(doubleLog.Elmore, 'name')    <- 'doubleLog.Elmore'
 attr(doubleLog.Elmore, 'par')     <- c("mn", "mx", "sos", "rsp", "eos", "rau", "m7")
 attr(doubleLog.Elmore, 'formula') <- expression( mn + (mx - m7*t)*( 1/(1 + exp(-rsp*(t-sos))) - 1/(1 + exp(-rau*(t-eos))) ) )
 
@@ -153,7 +146,6 @@ doubleLog.Gu <- function(par, t) {
     pred <- y0 + (a1/(1 + exp(-rsp*(t - sos)))^c1) - (a2/(1 + exp(-rau*(t - eos)))^c2)
     return(pred)
 }
-attr(doubleLog.Gu, 'name')    <- 'doubleLog.Gu'
 attr(doubleLog.Gu, 'par')     <- c('y0', 'a1', 'a2', 'sos', 'rsp', 'eos', 'rau', 'c1', 'c2')
 attr(doubleLog.Gu, 'formula') <- expression(y0 + (a1/(1 + exp(-rsp*(t - sos)))^c1) - (a2/(1 + exp(-rau*(t - eos)))^c2))
 
@@ -177,7 +169,6 @@ doubleLog.Klos <- function(par, t) {
         - 1/(1 + q2 * exp(-B2 * (t - m2)))^v2)
     return(pred)
 }
-attr(doubleLog.Klos, 'name')    <- 'doubleLog.Klos'
 attr(doubleLog.Klos, 'par')     <- c('a1', 'a2', 'b1', 'b2', 'c', 'B1', 'B2',
     'm1', 'm2', 'q1', 'q2', 'v1', 'v2')
 attr(doubleLog.Klos, 'formula') <- expression((a1*t + b1) + (a2*t^2 + b2*t + c) * (1/(1 + q1 * exp(-B1 * (t - m1)))^v1
@@ -200,89 +191,11 @@ attr(doubleLog.Klos, 'formula') <- expression((a1*t + b1) + (a2*t^2 + b2*t + c)
 # npar <- nrow(vc)
 # s2 <- opt.df$cost[best]^2 / (n - npar)
 # std.errors <- sqrt(diag(vc) * s2)     # standard errors
-# return: stdError=std.error
-
-#' Goal function of fine curve fitting methods
-#'
-#' @inheritParams optim_pheno
-#' @inheritParams Logistic
-#'
-#' @param fun A curve fitting function, can be one of `doubleAG`, 
-#' `doubleLog.Beck`, `doubleLog.Elmore`, `doubleLog.Gu`, 
-#' `doubleLog.Klos`, `doubleLog.Zhang`, see [Logistic()] 
-#' for details.
-#' @param ... others will be ignored.
-#'
-#' @return RMSE Root Mean Square Error of curve fitting values.
-#' 
-#' @examples
-#' library(phenofit)
-#' # simulate vegetation time-series
-#' fFUN = doubleLog.Beck
-#' par  = c(
-#'     mn  = 0.1,
-#'     mx  = 0.7,
-#'     sos = 50,
-#'     rsp = 0.1,
-#'     eos = 250,
-#'     rau = 0.1)
-#' t    <- seq(1, 365, 8)
-#' tout <- seq(1, 365, 1)
-#' y <- fFUN(par, t)
-#' 
-#' par0 <- c(
-#'     mn  = 0.15,
-#'     mx  = 0.65,
-#'     sos = 100,
-#'     rsp = 0.12,
-#'     eos = 200,
-#'     rau = 0.12)
-#' f_goal(par0, y, t, fFUN)
-#' @export
-f_goal <- function(
-    par, y, t,
-    fun,
-    w, ylu, ...)
-{
-    # FUN <- match.fun(fun)
-    if (!all(is.finite(par))) return(9999)
-
-    pred <- fun(par, t = t)
-    # If have no finite values, return 9999
-    if (!all(is.finite(pred))) return(9999) # for Klos fitting
-    if (missing(w)) w <- rep(1, length(y))
-
-    if (!missing(ylu)){
-        # points out of ylu should be punished!
-        w[pred < ylu[1] | pred > ylu[2]] <- 0
-        # pred   <- check_ylu(pred, ylu)
-    }
-    SSE  <- sum((y - pred)^2 * w)
-    RMSE <- sqrt(SSE/length(y))
-    # NSE  <- SSE/sum((y - mean(pred))^2)
-
-    # 1. better handle low and high values simulation
-    # xpred_2 <- sqrt(xpred_2)
-    # x_2     <- sqrt(x_2)
-    # xpred_2 <- log(xpred_2+1)
-    # x_2     <- log(x_2+1)
-    # xpred_2 <- 1/pred          # inverse NSE
-    # x_2     <- 1/y
-
-    # xpred_2 <- pred - mean(y)
-    # x_2     <- y - mean(y)
-    # NSE2 <- sum((x_2 - xpred_2)^2 * w)/sum((x_2 - mean(x_2))^2) #NSE
-
-    # const <- ylu[2]
-    # xpred_2 <- pred - ylu[1]; xpred_2[xpred_2 < 0] <- const
-    # x_2     <- y     - ylu[1]; x_2[x_2 < 0] <- const
-    return(RMSE)
-}
 
 # attach gradient and hessian analytical function to curve fitting functions
 .dls <- lapply(
     c("doubleLog.Beck", "doubleLog.Elmore", "doubleLog.Gu",
-      "doubleLog.Klos", "doubleLog.Zhang", "doubleAG"),
+      "doubleLog.Klos", "doubleLog.Zhang", "doubleLog.AG"),
     function (FUN){
         # FUN <- deparse(substitute(fun))
         fun <- get(FUN)
