@@ -32,19 +32,30 @@
 #' @param ... other paraters passed to [optim_pheno()].
 #'
 #' @return
-#' \describe{
-#' \item{tout}{The time of output curve fitting time-series.}
-#' \item{zs}{Smoothed vegetation time-series of every iteration.}
-#' \item{ws}{Weights of every iteration.}
-#' \item{par}{Final optimized parameter of fine fitting.}
-#' \item{fun}{The name of fine fitting.}
-#' }
+#' - `tout`: The time of output curve fitting time-series.
+#' - `zs`  : Smoothed vegetation time-series of every iteration.
+#' - `ws`  : Weights of every iteration.
+#' - `par` : Final optimized parameter of fine fitting.
+#' - `fun` : The name of fine fitting.
 #' 
 #' @references
 #' 1. Beck, P.S.A., Atzberger, C., Hogda, K.A., Johansen, B., Skidmore, A.K.,
 #'      2006. Improved monitoring of vegetation dynamics at very high latitudes:
 #'      A new method using MODIS NDVI. Remote Sens. Environ.
 #'      https://doi.org/10.1016/j.rse.2005.10.021.
+#' 2. Elmore, A.J., Guinn, S.M., Minsley, B.J., Richardson, A.D., 2012.
+#'      Landscape controls on the timing of spring, autumn, and growing season
+#'      length in mid-Atlantic forests. Glob. Chang. Biol. 18, 656-674.
+#'      https://doi.org/10.1111/j.1365-2486.2011.02521.x. \cr
+#' 
+#' 3. Gu, L., Post, W.M., Baldocchi, D.D., Black, TRUE.A., Suyker, A.E., Verma,
+#'      S.B., Vesala, TRUE., Wofsy, S.C., 2009. Characterizing the Seasonal Dynamics
+#'      of Plant Community Photosynthesis Across a Range of Vegetation Types,
+#'      in: Noormets, A. (Ed.), Phenology of Ecosystem Processes: Applications
+#'      in Global Change Research. Springer New York, New York, NY, pp. 35-58.
+#'      https://doi.org/10.1007/978-1-4419-0026-5_2. \cr
+#'
+#' 4. https://github.com/kongdd/phenopix/blob/master/R/FitDoubleLogGu.R
 #' @example inst/examples/ex-FitDL.R
 NULL
 
@@ -57,6 +68,7 @@ FitDL.Zhang <- function(y, t = index(y), tout = t,
     e <- init_param(y, t, w)
 
     sFUN    <- "doubleLog.Zhang"
+    
     prior  <- with(e, rbind(
         c(doy.mx   , mn, mx, doy[1]   , k  , doy[2]   , k  ),
         c(doy.mx   , mn, mx, doy[1]+t1, k*2, doy[2]-t1, k*2),
@@ -69,20 +81,20 @@ FitDL.Zhang <- function(y, t = index(y), tout = t,
 
     # lower[["r"]] %>% multiply_by(1/3)
     # upper[["r"]] %>% multiply_by(3)
-    # browser()
     optim_pheno(prior, sFUN, y, t, tout, method, w, lower = lower, upper = upper, ...)
 }
 
 #' @rdname FitDL
 #' @export
-FitAG <- function(y, t = index(y), tout = t, 
+FitDL.AG <- function(y, t = index(y), tout = t, 
     method = 'nlminb', w, ...)
 {
     if (missing(w)) w <- rep(1, length(y))
     e <- init_param(y, t, w)
     # print(ls.str(envir = e))
 
-    sFUN <- "doubleAG"
+    sFUN <- "doubleLog.AG"
+
     prior <- with(e, rbind(
         c(doy.mx, mn, mx, 1/half    , 2, 1/half, 2),
         # c(doy.mx, mn, mx, 0.2*half, 1  , 0.2*half, 1),
@@ -114,15 +126,7 @@ FitDL.Beck <- function(y, t = index(y), tout = t,
 
     optim_pheno(prior, sFUN, y, t, tout, method, w, lower = lower, upper = upper, ...)
 }
-# mn + (mx - mn)*(1/(1 + exp(-rsp*(t - sos))) + 1/(1 + exp(rau*(t - eos))))
-# attr(doubleLog.Beck, 'par') <- c("mn", "mx", "sos", "rsp", "eos", "rau")
-# attr(doubleLog.Beck, 'formula') <- expression(mn + (mx - mn)*(1/(1 + exp(-rsp*(t - sos))) + 1/(1 + exp(rau*(t - eos)))))
 
-#' @references
-#' 2. Elmore, A.J., Guinn, S.M., Minsley, B.J., Richardson, A.D., 2012.
-#'      Landscape controls on the timing of spring, autumn, and growing season
-#'      length in mid-Atlantic forests. Glob. Chang. Biol. 18, 656-674.
-#'      https://doi.org/10.1111/j.1365-2486.2011.02521.x. \cr
 #' @rdname FitDL
 #' @export
 FitDL.Elmore <- function(y, t = index(y), tout = t, 
@@ -132,15 +136,18 @@ FitDL.Elmore <- function(y, t = index(y), tout = t,
 
     # doy_q  <- quantile(t, c(0.1, 0.25, 0.5, 0.75, 0.9), na.rm = TRUE)
     sFUN   <- "doubleLog.Elmore"
+    
+    # TODO: remove bad one 
+    # generally m7 < 0.001
     prior <- with(e, rbind(
         c(mn, mx - mn, doy[1]+t1, k*2.5  , doy[2]-t2, k*2.5  , 0.002),
-        c(mn, mx - mn, doy[1]   , k*1.25 , doy[2]   , k*1.25 , 0.002),
-        c(mn, mx - mn, doy[1]   , k*1  , doy[2]   , k*0.5  , 0.05),
-        c(mn, mx - mn, doy[1]-t1, k*1 , doy[2]+t2, k*0.25, 0.1)))
-    # xpred <- m1 + (m2 - m7*t)*((1/(1 + exp((m3l - t)/m4l))) - (1/(1 + exp((m5l - t)/m6l))))
+        # c(mn, mx - mn, doy[1]   , k*1.25 , doy[2]   , k*1.25 , 0.002),
+        # c(mn, mx - mn, doy[1]   , k*1    , doy[2]   , k      , 0.001),
+        c(mn, mx - mn, doy[1]-t1, k*0.25   , doy[2]+t2, k*0.25 , 0.001)
+    ))
     param_lims <- e$lims[c('mn', 'mx', 'sos', 'r', 'eos', 'r')]
-    lower  <- c(sapply(param_lims, `[`, 1), 0  )
-    upper  <- c(sapply(param_lims, `[`, 2), Inf)
+    lower  <- c(sapply(param_lims, `[`, 1), 0)
+    upper  <- c(sapply(param_lims, `[`, 2), 1)
 
     optim_pheno(prior, sFUN, y, t, tout, method, w, lower = lower, upper = upper, ...)
 }
@@ -150,20 +157,6 @@ FitDL.Elmore <- function(y, t = index(y), tout = t,
 # c(mn, mx - mn, doy[1], half*0.5, doy[4], half*0.5, 0.05),
 # c(mn, mx - mn, doy[1], half*0.8, doy[5], half*0.8, 0.1))
 
-# attr(doubleLog.Elmore, 'name')    <- 'doubleLog.Elmore'
-# attr(doubleLog.Elmore, 'par')     <- c("mn", "mx", "sos", "rsp", "eos", "rau", "m7")
-# attr(doubleLog.Elmore, 'formula') <- expression( mn + (mx - m7*t)*( 1/(1 + exp(-rsp*(t-sos))) - 1/(1 + exp(-rau*(t-eos))) ) )
-
-#' @references
-#' 3. Gu, L., Post, W.M., Baldocchi, D.D., Black, TRUE.A., Suyker, A.E., Verma,
-#'      S.B., Vesala, TRUE., Wofsy, S.C., 2009. Characterizing the Seasonal Dynamics
-#'      of Plant Community Photosynthesis Across a Range of Vegetation Types,
-#'      in: Noormets, A. (Ed.), Phenology of Ecosystem Processes: Applications
-#'      in Global Change Research. Springer New York, New York, NY, pp. 35-58.
-#'      https://doi.org/10.1007/978-1-4419-0026-5_2. \cr
-#'
-#' 4. https://github.com/kongdd/phenopix/blob/master/R/FitDoubleLogGu.R
-#'
 #' @rdname FitDL
 #' @export
 FitDL.Gu <- function(y, t = index(y), tout = t, 
@@ -182,7 +175,7 @@ FitDL.Gu <- function(y, t = index(y), tout = t,
     prior <- with(e, rbind(
         # c(mn, a, a, doy[1]-t1, k/2 , doy[2]+t2, k/2, 1  , 1),
         c(mn, a, a, doy[1]   , k   , doy[2]   , k  , 2  , 2),
-        c(mn, a, a, doy[1]   , k*2 , doy[2]   , k*2, 3  , 3),
+        # c(mn, a, a, doy[1]   , k*2 , doy[2]   , k*2, 3  , 3),
         c(mn, a, a, doy[1]+t1, k*2 , doy[2]-t2, k*2, 0.5, 0.5),
         c(mn, a, a, doy[1]+t1, k*3 , doy[2]-t2, k*3, 5  , 5)))
     # y0 + (a1/(1 + exp(-(t - t1)/b1))^c1) - (a2/(1 + exp(-(t - t2)/b2))^c2)
@@ -233,4 +226,3 @@ FitDL.Klos <- function(y, t = index(y), tout = t,
     sFUN <- "doubleLog.Klos"
     optim_pheno(prior, sFUN, y, t, tout, method, w, ...)
 }
-
